# -*- coding: utf-8 -*-

import unittest

from web_scrapper import Team


class TeamTestCase(unittest.TestCase):

    def test_wta_single(self):
        src = []
        t1 = Team.from_wta(u'Maña', u'(ITA)', u'75 64', True)
        t2 = Team.from_wta(u'Maña', u'(ITA)', u'75 64', False)

        self.assertTrue(t1.singles)
        self.assertEqual(t1.name, u'Maña')
        self.assertEqual(t1.nation, [u'ITA'])
        self.assertEqual(t1.scores, [7, 6, 0, 0, 0])
        self.assertEqual(t1.tbreaks, [0, 0, 0, 0, 0])

        self.assertTrue(t2.singles)
        self.assertEqual(t2.scores, [5, 4, 0, 0, 0])
        self.assertEqual(t2.tbreaks, [0, 0, 0, 0, 0])

    def test_wta_double(self):
        t = Team.from_wta(u'Errani/Vinci', u'(ITA/VZL)', u'64 75', True)
        self.assertFalse(t.singles)
        self.assertEqual(t.name, u'Errani/Vinci')
        self.assertEqual(t.nation, [u'ITA', u'VZL'])

    def test_wta_tbreaks(self):
        t1 = Team.from_wta(u'Maña', u'(ITA)', u'76(4) 61', True)
        t2 = Team.from_wta(u'Maña', u'(ITA)', u'76(4) 61', False)

        self.assertEqual(t1.scores, [7, 6, 0, 0, 0])
        self.assertEqual(t1.tbreaks, [7, 0, 0, 0, 0])

        self.assertEqual(t2.scores, [6, 1, 0, 0, 0])
        self.assertEqual(t2.tbreaks, [4, 0, 0, 0, 0])

    def test_wta_long_result(self):
        t1 = Team.from_wta(u'Maña', u'(ITA)', u'67(5) 62 105', True)
        t2 = Team.from_wta(u'Maña', u'(ITA)', u'67(5) 62 105', False)

        self.assertEqual(t1.scores, [6, 6, 10, 0, 0])
        self.assertEqual(t1.tbreaks, [5, 0, 0, 0, 0])

        self.assertEqual(t2.scores, [7, 2, 5, 0, 0])
        self.assertEqual(t2.tbreaks, [7, 0, 0, 0, 0])
